@@ -5,6 +5,8 @@
 #'
 #' @param warp_data fdawarp object from [time_warping] of aligned data
 #' @param no number of principal components to extract
+#' @param var_exp compute no based on value percent variance explained (example: 0.95)
+#'                will override `no`
 #' @param ci geodesic standard deviations (default = c(-1,0,1))
 #' @param showplot show plots of principal directions (default = T)
 #' @return Returns a hfpca object containing \item{gam_pca}{warping functions principal directions}
@@ -20,13 +22,12 @@
 #' @export
 #' @examples
 #' hfpca <- horizFPCA(simu_warp, no = 3)
-horizFPCA <- function(warp_data,no,ci=c(-1,0,1),showplot = TRUE){
+horizFPCA <- function(warp_data, no=3, var_exp=NULL, ci=c(-1,0,1),
+                      showplot = TRUE){
     gam <- warp_data$warping_functions
     tmp = SqrtMean(gam)
     vec = tmp$vec
     mu = tmp$mu
-    # Parameters
-    no_pca = 1:no
 
     # TFPCA
     K = stats::cov(t(vec)) #out$sigma
@@ -37,6 +38,15 @@ horizFPCA <- function(warp_data,no,ci=c(-1,0,1),showplot = TRUE){
     TT = nrow(vec) + 1
     vm = rowMeans(vec)
 
+    # Parameters
+    if (!is.null(var_exp)){
+      cumm_coef <- cumsum(s)/sum(s)
+      tmp = which(cumm_coef <= var_exp)
+      no = tmp[length(tmp)]
+    }
+
+    no_pca = 1:no
+
     gam_pca = array(0,dim=c(length(ci),length(mu)+1,no))
     psi_pca = array(0,dim=c(length(ci),length(mu),no))
     for (j in no_pca){
@@ -72,6 +82,8 @@ horizFPCA <- function(warp_data,no,ci=c(-1,0,1),showplot = TRUE){
     hfpca$coef = c[,no_pca]
     hfpca$vec = vec
     hfpca$mu = mu
+    hfpca$vm = vm
+    hfpca$warp_data = warp_data
 
     class(hfpca) <- "hfpca"
 
